## 0.3.0 (2025-03-04)

### Feat

- add scheduler script
- add holiday detection and asynchronous publishing

[main 2b9d948] bump: version 0.2.1 → 0.3.0
 2 files changed, 2 insertions(+), 2 deletions(-)

